local GH = GarrisonHelper
local L = GH.L
-- Frame and Events
local GarrisonHelper_Events = CreateFrame("Frame");
local events = {};
local addonName = ...
local formattedName = "|r|cFFFF7700<"..addonName..">|r"
GH.dataobj = GH.LDB:NewDataObject(addonName, {label = formattedName, type = "data source", icon = "Interface\\Icons\\garrison_build.blp", text = nil})

if GH.dataobj then
	
	function GH.dataobj:OnEnter()
		--print("#1#"..tostring(self))
		GH:ScanGarrisonOverlayButton(self)
		--if not GH_OverlayButton then
			GH:BrokerTooltip(self)
		--end
	end
	
	function GH.dataobj:OnLeave()
		GameTooltip:Hide()
	end

	function GH.dataobj:OnClick(button)
		if button == "LeftButton" and IsShiftKeyDown() then
			--GH:print(button .. " and shift")
			SlashCmdList["GARRISONHELPER"]()
		elseif button == "LeftButton" then
			--GH:print(button)
			SlashCmdList["GARRISONHELPER"]()
		elseif button == "RightButton" then
			--GH:print(button)
			SlashCmdList["GARRISONHELPER"]()
		end
	end
end

function GH:BrokerTooltip(self)
	if GH.tip then GH.tip:Hide() end
	
	if GH.db.profile.tooltipincombat and InCombatLockdown() then return end
	
	GH.tip = GH.TT:Acquire("GH_Tooltip", 2, "LEFT", "RIGHT")
	
	local tip = GH.tip
	if self then
		tip:SmartAnchorTo(self)
		tip:SetAutoHideDelay(0.25, self)
	end
	tip:Clear()
	
	if #C_Garrison.GetBuildings() > 0 then
		GH:UpdateBrokerText()
		if GH.dataobj.text then tip:AddHeader(GH.dataobj.text) tip:AddLine("") tip:AddSeparator() end
		GH:GetArmoryTooltip()
		GH:GetJewelcraftingTooltip()
		GH:GetScribeTooltip()
		GH:GetAlchemyTooltip()
		GH:GetDailyVisitorsTooltip()
		
		tip:AddLine("\n")
		tip:AddSeparator()
		tip:AddLine("")
		if GH:InsideGarrison() then
			tip:AddLine("|TInterface\\TUTORIALFRAME\\UI-TUTORIAL-FRAME:21:18:0:-1:512:512:10:70:226:306|t ".. L["to scan for NPCs in your garrison"])
		end
		tip:AddLine("|TInterface\\TUTORIALFRAME\\UI-TUTORIAL-FRAME:21:18:0:-1:512:512:10:70:330:410|t "..L["to open configuration"])
	else
		tip:AddLine(L["No supported garrison buildings found."].."\n"..formattedName.." "..L["can't help this character."])
	end
	
	if self then
		tip:Show()
	end
end

function GH:AddTooltipSeparatorLine(height, r, g, b, a)
	local lineNum, colNum = GameTooltip:AddLine()
	print(lineNum)
	local line = GameTooltip.lines[lineNum]
	local color = _G.NORMAL_FONT_COLOR

	height = height or 1
	SetTooltipSize(GameTooltip, GameTooltip.width, GameTooltip.height + height)
	line.height = height
	line:SetHeight(height)
	line:SetBackdrop(GenericBackdrop)
	line:SetBackdropColor(r or color.r, g or color.g, b or color.b, a or 1)
	return lineNum, colNum
end

function GH:UpdateBrokerText()
	if GH.dataobj then
		local c = GH:GetOpenTaskCount()
		GH.dataobj.text = c .. " " .. (c==1 and L["task"] or L["tasks"]) .. " "..L["open"]
	end
end

function GH:GetOpenTaskCount()
	return GH:GetArmoryOpenTaskCount()+GH:GetScribeOpenTaskCount()+GH:GetJewelcraftingOpenTaskCount()
end


function UpdateDisplay()
	if GH.dataobj then
		GH:UpdateBrokerText()
		C_Timer.After(10, UpdateDisplay)
	end
end
C_Timer.After(5, UpdateDisplay)



-- register event listener
GarrisonHelper_Events:SetScript("OnEvent", function(self, event, ...) GH:UpdateBrokerText() end);
GarrisonHelper_Events:RegisterEvent("QUEST_FINISHED");
GarrisonHelper_Events:RegisterEvent("BAG_UPDATE");
GarrisonHelper_Events:RegisterEvent("BAG_UPDATE_DALAYED");
